@@ -47,6 +47,8 @@ def test_resume_uploads_script(keyfile):
         'server': None,
         'uuid': 'some-guid',
         'upload_folder': None,
+        'no_query': False,
+        'subfolders': False,
     })
     expect_call_args = {
         'bundle_filename': 'some.file',
@@ -54,6 +56,8 @@ def test_resume_uploads_script(keyfile):
         'server': None,
         'uuid': 'some-guid',
         'upload_folder': None,
+        'no_query': False,
+        'subfolders': False,
     }
     test_it(args_in=['-b', 'some.file', 'some-guid'],
             expect_exit_code=0,
@@ -69,6 +73,8 @@ def test_resume_uploads_script(keyfile):
         'server': None,
         'uuid': 'some-guid',
         'upload_folder': None,
+        'no_query': False,
+        'subfolders': False,
     }
     test_it(args_in=['some-guid', '-b', 'some.file', '-e', 'some-env'],
             expect_exit_code=0,
@@ -84,6 +90,8 @@ def test_resume_uploads_script(keyfile):
         'server': 'http://some.server',
         'uuid': 'some-guid',
         'upload_folder': None,
+        'no_query': False,
+        'subfolders': False,
     }
     test_it(args_in=['some-guid', '-b', 'some.file', '-e', 'some-env', '-s', 'http://some.server'],
             expect_exit_code=0,
@@ -99,6 +107,8 @@ def test_resume_uploads_script(keyfile):
         'server': 'http://some.server',
         'uuid': 'some-guid',
         'upload_folder': 'a-folder',
+        'no_query': False,
+        'subfolders': False,
     }
     test_it(args_in=['some-guid', '-b', 'some.file', '-e', 'some-env', '-s', 'http://some.server', '-u', 'a-folder'],
             expect_exit_code=0,
@@ -109,6 +119,32 @@ def test_resume_uploads_script(keyfile):
             expect_exit_code=0,
             expect_called=True,
             expect_call_args=expect_call_args)
+    expect_call_args = {
+        'bundle_filename': 'some.file',
+        'env': None,
+        'server': 'http://some.server',
+        'uuid': 'some-guid',
+        'upload_folder': 'a-folder',
+        'no_query': True,
+        'subfolders': False,
+    }
+    test_it(args_in=['some-guid', '-b', 'some.file', '-s', 'http://some.server', '-u', 'a-folder', '-nq'],
+            expect_exit_code=0,
+            expect_called=True,
+            expect_call_args=expect_call_args)
+    expect_call_args = {
+        'bundle_filename': 'some.file',
+        'env': None,
+        'server': 'http://some.server',
+        'uuid': 'some-guid',
+        'upload_folder': 'a-folder',
+        'no_query': True,
+        'subfolders': True,
+    }
+    test_it(args_in=['some-guid', '-b', 'some.file', '-s', 'http://some.server', '-u', 'a-folder', '-nq', '-sf'],
+            expect_exit_code=0,
+            expect_called=True,
+            expect_call_args=expect_call_args)
 
 
 SAMPLE_UPLOAD_INFO = [
